@@ -16,7 +16,7 @@ int main(int argc, char **argv) {
 		exit(1);
 	}
 
-	chdir("/dev");	
+	chdir("/dev/.initramfs");	
 
 	pipe_fd = open(USPLASH_FIFO,O_WRONLY|O_NONBLOCK);
 	
